@@ -1,6 +1,6 @@
 from .gtfs_service import Service_Utils
 
 
-def load_gtfs(gtfs_dir, service_date, start_time, end_time):
+def load_gtfs(gtfs_dir, service_date):
     gtfs_service = Service_Utils(gtfs_dir, service_date)
     return gtfs_service
